==> apache-shenyu-incubating-2.4.2-src.zip: apache-shenyu-incubating-2.4.2-src/shenyu-admin/src/test/java/org/apache/shenyu/admin/config/WebsocketSyncPropertiesTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.admin.config;

import org.apache.shenyu.admin.AbstractConfigurationTest;
import org.apache.shenyu.admin.config.properties.WebsocketSyncProperties;
import org.junit.Test;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Configuration;
import static org.hamcrest.Matchers.comparesEqualTo;
import static org.hamcrest.Matchers.is;
import static org.junit.Assert.assertThat;

/**
 * Test cases for WebsocketSyncProperties.
 */
public final class WebsocketSyncPropertiesTest extends AbstractConfigurationTest {

    @Test
    public void testWebsocketSyncPropertiesDefaultValue() {
        assertThat(new WebsocketSyncProperties().isEnabled(), is(true));
    }

    @Test
    public void testWebsocketSyncPropertiesSetValue() {
        load(WebsocketSyncPropertiesConfiguration.class, "shenyu.sync.websocket.enabled=false");
        WebsocketSyncProperties websocketSyncProperties = getContext().getBean(WebsocketSyncProperties.class);
        assertThat(websocketSyncProperties.isEnabled(), comparesEqualTo(false));
    }

    @Configuration
    @EnableConfigurationProperties(WebsocketSyncProperties.class)
    static class WebsocketSyncPropertiesConfiguration {
    }
}

==> apache-shenyu-incubating-2.4.3-src.zip: apache-shenyu-incubating-2.4.3-src/shenyu-admin/src/test/java/org/apache/shenyu/admin/config/WebsocketSyncPropertiesTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.admin.config;

import org.apache.shenyu.admin.AbstractConfigurationTest;
import org.apache.shenyu.admin.config.properties.WebsocketSyncProperties;
import org.junit.jupiter.api.Test;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Configuration;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.comparesEqualTo;
import static org.hamcrest.Matchers.is;

/**
 * Test cases for WebsocketSyncProperties.
 */
public final class WebsocketSyncPropertiesTest extends AbstractConfigurationTest {

    @Test
    public void testWebsocketSyncPropertiesDefaultValue() {
        assertThat(new WebsocketSyncProperties().isEnabled(), is(true));
    }

    @Test
    public void testWebsocketSyncPropertiesSetValue() {
        load(WebsocketSyncPropertiesConfiguration.class, "shenyu.sync.websocket.enabled=false");
        WebsocketSyncProperties websocketSyncProperties = getContext().getBean(WebsocketSyncProperties.class);
        assertThat(websocketSyncProperties.isEnabled(), comparesEqualTo(false));
    }

    @Configuration
    @EnableConfigurationProperties(WebsocketSyncProperties.class)
    static class WebsocketSyncPropertiesConfiguration {
    }
}
